@@ -32,6 +32,8 @@ extern "C" {
 #include <inttypes.h>
 #include <stddef.h>
 
+#pragma GCC visibility push(default)
+  
 /* Some public enums needed by most subsequent headers */
 
 /**
@@ -286,7 +288,8 @@ typedef enum
     LQT_SAMPLE_UINT8,     /*!< uint8_t */
     LQT_SAMPLE_INT16,     /*!< int16_t */
     LQT_SAMPLE_INT32,     /*!< int32_t */
-    LQT_SAMPLE_FLOAT      /*!< Float (machine native) */
+    LQT_SAMPLE_FLOAT,     /*!< Float (machine native) */
+    LQT_SAMPLE_DOUBLE     /*!< Double (machine native, since version 1.0.3) */
   } lqt_sample_format_t;
   
 /** \ingroup general
@@ -1288,7 +1291,8 @@ int64_t quicktime_byte_position(quicktime_t *file);
   
 void quicktime_set_avi(quicktime_t *file, int value);
 
-  
+#pragma GCC visibility pop
+
 
 #ifdef __cplusplus
 }
