@@ -1,10 +1,32 @@
-#include "funcprotos.h"
-#include <quicktime/colormodels.h>
-#include <quicktime/quicktime.h>
-#include <workarounds.h>
+/*******************************************************************************
+ v410.c
 
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include "workarounds.h"
+#include "videocodec.h"
+#include <quicktime/colormodels.h>
 #include <stdlib.h>
-#include <string.h>
 
 typedef struct
   {
@@ -98,8 +120,10 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
           }
 
         if(!codec->buffer)
+          {
+          lqt_set_fiel_uncompressed(file, track);
           codec->buffer = malloc(width * height * 4);
-
+          }
         out_ptr = codec->buffer;
 	for(i = 0; i < height; i++)
           {
@@ -130,7 +154,6 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 		vtrack->current_chunk,
 		&chunk_atom, 
 		1);
-//printf("quicktime_encode_yv12 2\n");
 
 	vtrack->current_chunk++;
 	
